/*
 * Fabric3
 * Copyright (c) 2009 Metaform Systems
 *
 * Fabric3 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version, with the
 * following exception:
 *
 * Linking this software statically or dynamically with other
 * modules is making a combined work based on this software.
 * Thus, the terms and conditions of the GNU General Public
 * License cover the whole combination.
 *
 * As a special exception, the copyright holders of this software
 * give you permission to link this software with independent
 * modules to produce an executable, regardless of the license
 * terms of these independent modules, and to copy and distribute
 * the resulting executable under terms of your choice, provided
 * that you also meet, for each linked independent module, the
 * terms and conditions of the license of that module. An
 * independent module is a module which is not derived from or
 * based on this software. If you modify this software, you may
 * extend this exception to your version of the software, but
 * you are not obligated to do so. If you do not wish to do so,
 * delete this exception statement from your version.
 *
 * Fabric3 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the
 * GNU General Public License along with Fabric3.
 * If not, see <http://www.gnu.org/licenses/>.
 *
 * ----------------------------------------------------
 *
 * Portions originally based on Apache Tuscany 2007
 * licensed under the Apache 2.0 license.
 *
 */
package org.fabric3.model.type.component;

import java.net.URI;
import java.util.ArrayList;
import java.util.List;

/**
 * Represents a component reference.
 *
 * @version $Rev: 7259 $ $Date: 2009-07-04 12:33:17 +0200 (Sat, 04 Jul 2009) $
 */
public class ComponentReference extends ReferenceDefinition {
    private static final long serialVersionUID = 2072898078368317712L;
    private boolean autowire;
    private List<URI> targets = new ArrayList<URI>();

    /**
     * Construct a ComponentReference specifying the name of the reference being configured.
     *
     * @param name the name of the reference being configured
     */
    public ComponentReference(String name) {
        super(name, null);
    }

    /**
     * Returns true if autowire is enabled for the reference.
     *
     * @return true if autowire is enabled for the reference.
     */
    public boolean isAutowire() {
        return autowire;
    }

    /**
     * Sets autowire enablement for the reference.
     *
     * @param autowire true if autowire is enabled.
     */
    public void setAutowire(boolean autowire) {
        this.autowire = autowire;
    }

    public List<URI> getTargets() {
        return targets;
    }

    public void addTarget(URI target) {
        targets.add(target);
    }

}
